==> dl.php?src=linea21_1_6.zip: linea21/templates/admin/default/header.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage admin
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
echo '<?xml version="1.0" encoding="' . CHARSET . '"  xml:lang="' .U_L. '" ?>'. END_LINE;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo U_L; ?>">
<head>
<title><?php echo _t('header','title');?></title>
<meta http-equiv="content-language" content="<?php echo U_L;?>" />
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET;?>" />
<link rel="shortcut icon" href="<?php echo THEME_ADMIN_PATH; ?>images/favicon.ico" />
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/reset.css" />
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_common.css" />
<?php
if (basename($_SERVER['SCRIPT_NAME']) != 'search.php') {
  if(file_exists(THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css')) {
  	echo '<style type="text/css" media="all">';
    echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css);';
    echo '</style>';
  }
} else {
	echo '<style type="text/css" media="all">';
	echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_search.css);';
	echo '</style>';
}
?>
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/button/stylesheets/css3buttons.css" media="screen" />
<!--[if lte IE 7]>
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_ie.css" />
<![endif]-->
<!--[if IE 8]>
<style type="text/css" media="all">
img { 
  	width: auto; /* for ie 8 because max-width does not work in ie8 */
  }
.dashboard-indicator-gauge {
	min-width:200px; /** fix bug on IE8 */
}
</style>
<![endif]-->
<script type="text/javascript">
var SITE_ROOT_URL= "<?php echo SITE_ROOT_URL; ?>";
var lang = "<?php echo U_L; ?>";
</script>
<script type="text/javascript" src="../lib/js/jquery.min.js"></script>
<link href="../lib/js/jquery-ui/css/ui-lightness/jquery-ui-1.8.16.custom.css" rel="stylesheet" type="text/css" />
<script type="text/javascript" src="../lib/js/jquery-ui/js/jquery-ui-1.8.16.custom.min.js"></script>
<script type="text/javascript" src="../lib/js/humane-js/humane.min.js"></script>
<link type="text/css" rel='stylesheet' href='../lib/js/humane-js/themes/jackedup.css' />
<?php IncludePHPDebug(); ?>
<?php IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']")); ?>
<?php IncludeMultiSelectJs(); ?>
<?php IncludeTreeJs(); ?>
<?php IncludeTooltipJs('abbr[title]'); ?>
<?php IncludeTextBoxListJs(); ?>
<?php IncludeTimeline(); ?>
<?php AddDynamicHeader(); ?>
<script type="text/javascript" src="../lib/js/functions_admin.js"></script>
</head>
<body>
<div id="container" style="background-image: url(<?php echo THEME_ADMIN_PATH; ?>images/bgcontainer.png);">
<!-- barre haute -->
<div id="tools_right">
  <div id="deconnexion">
  	<a href="logout.php"><?php echo _t('header','deconnexion');?></a>
  </div>
  <br style="clear:both;"/>
  <div id="bienvenue">
    <?php
    if($l21auth->GetSessionElement('firstname')) $title= ucfirst($l21auth->GetSessionElement('firstname'));
    else $title= $l21auth->GetSessionElement('login');
    
    echo _t('header','welcome');
    ?>
    <span><?php echo $title; ?></span>
  </div>
  <br style="clear:both;"/>
  <div id="containersearch">
  	<form method="post" action="search.php">
  		<input type="text" class="searchincome" name="search" id="searchincome"  accesskey="s" value="<?php echo _t('menu_alt','search_here'); ?>" onclick="if (this.defaultValue==this.value) this.value=''" onblur="if (this.value=='') this.value=this.defaultValue" />
  		<input type="submit" id="gosearch"   name="valid" value="" />
  		</form>
  </div>
</div>
<!--end barre haute -->

==> dl.php?src=linea21_1_7.zip: linea21/templates/admin/default/header.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage admin
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
echo '<?xml version="1.0" encoding="' . CHARSET . '"  xml:lang="' .U_L. '" ?>'. END_LINE;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo U_L; ?>">
<head>
<title><?php echo _t('header','title');?></title>
<meta http-equiv="content-language" content="<?php echo U_L;?>" />
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET;?>" />
<link rel="shortcut icon" href="<?php echo THEME_ADMIN_PATH; ?>images/favicon.ico" />
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/reset.css" />
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_common.css" />
<?php
// must be included before calling admin_system.css to be able to style .codeMirror
includeCodeEditor();

if (basename($_SERVER['SCRIPT_NAME']) != 'search.php') {
  if(file_exists(THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css')) {
  	echo '<style type="text/css" media="all">';
    echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css);';
    echo '</style>';
  }
} else {
	echo '<style type="text/css" media="all">';
	echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_search.css);';
	echo '</style>';
}
?>
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/button/stylesheets/css3buttons.css" media="screen" />
<link type="text/css" rel="stylesheet" href="../lib/vendor/fontello/css/app.css" />
<link type="text/css" rel="stylesheet" href="../lib/vendor/fontello/css/animation.css" />
<!--[if IE 7]>
<link rel="stylesheet" href="../lib/vendor/fontello/css/app-ie7.css">
<![endif]-->
<!--[if lte IE 7]>
<link type="text/css" rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_ie.css" />
<![endif]-->
<!--[if IE 8]>
<style type="text/css" media="all">
img { 
  	width: auto; /* for ie 8 because max-width does not work in ie8 */
  }
.dashboard-indicator-gauge {
	min-width:200px; /** fix bug on IE8 */
}
</style>
<![endif]-->
<script type="text/javascript">
var SITE_ROOT_URL= "<?php echo SITE_ROOT_URL; ?>";
var lang = "<?php echo U_L; ?>";
</script>
<script type="text/javascript" src="../lib/js/jquery.min.js"></script>
<link href="../lib/js/jquery-ui/css/ui-lightness/jquery-ui-1.10.3.custom.min.css" rel="stylesheet" type="text/css" />
<script type="text/javascript" src="../lib/js/jquery-ui/js/jquery-ui-1.10.3.custom.min.js"></script>
<script type="text/javascript" src="../lib/js/humane-js/humane.min.js"></script>
<link type="text/css" rel='stylesheet' href='../lib/js/humane-js/themes/jackedup.css' />
<?php IncludePHPDebug(); ?>
<?php IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']")); ?>
<?php IncludeTreeJs(); ?>
<?php IncludeTooltipJs('abbr[title]'); ?>
<?php IncludeTimeline(); ?>
<?php AddDynamicHeader(); ?>
<script type="text/javascript" src="../lib/js/functions_admin.js"></script>
</head>
<body>
<div id="container" style="background-image: url(<?php echo THEME_ADMIN_PATH; ?>images/bgcontainer.png);">
<!-- barre haute -->
<div id="tools_right">
  <br style="clear:both;"/>
  <div id="bienvenue">
    <?php
    if($l21auth->GetSessionElement('firstname')) $title= ucfirst($l21auth->GetSessionElement('firstname'));
    else $title= $l21auth->GetSessionElement('login');
    
    echo _t('header','welcome');
    ?>
    <span><?php echo $title; ?></span>
  </div>
  <div id="deconnexion">
  	<a href="logout.php"><i class="icon-off icon-big"></i><?php echo _t('header','deconnexion');?></a>
  </div>
  <br style="clear:both;"/>
  <div id="containersearch">
  	<form method="post" action="search.php">
  		<input type="text" class="searchincome" name="search" id="searchincome"  accesskey="s" value="<?php echo _t('menu_alt','search_here'); ?>" onclick="if (this.defaultValue==this.value) this.value=''" onblur="if (this.value=='') this.value=this.defaultValue" />
  		<input type="submit" id="gosearch"   name="valid" value="" />
  		</form>
  </div>
</div>
<!--end barre haute -->
